@@ -1,9 +1,20 @@
 # HEADER ####################################################
-# This is file  spam/R/dist.R.                              #
-# This file is part of the spam package,                    #
-#      http://www.math.uzh.ch/furrer/software/spam/         #
+# This is file spam/R/dist.R.                               #
+# It is part of the R package spam,                         #
+#  --> https://CRAN.R-project.org/package=spam              #
+#  --> https://CRAN.R-project.org/package=spam64            #
+#  --> https://git.math.uzh.ch/reinhard.furrer/spam         #
 # by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
-#    Daniel Gerber [ctb], Kaspar Moesinger [ctb]            #
+#    Daniel Gerber [ctb], Kaspar Moesinger [ctb],           #
+#    Youcef Saad [ctb] (SPARSEKIT),                         #
+#    Esmond G. Ng [ctb] (Fortran Cholesky routines),        #
+#    Barry W. Peyton [ctb] (Fortran Cholesky routines),     #
+#    Joseph W.H. Liu [ctb] (Fortran Cholesky routines),     #
+#    Alan D. George [ctb] (Fortran Cholesky routines),      #
+#    Esmond G. Ng [ctb] (Fortran Cholesky routines),        #
+#    Barry W. Peyton [ctb] (Fortran Cholesky routines),     #
+#    Joseph W.H. Liu [ctb] (Fortran Cholesky routines),     #
+#    Alan D. George [ctb] (Fortran Cholesky routines)       #
 # HEADER END ################################################
 
 
@@ -105,7 +116,7 @@ nearest.dist <- function( x, y=NULL, method = "euclidean",
   
   # EXPLICIT-STORAGE-FORMAT     
   if(max(n1,n2,nnz) > 2147483647 - 1 | getOption("spam.force64"))
-      SS <- .format64
+      SS <- .format64()
   else
       SS <- .format32
   
@@ -151,7 +162,7 @@ nearest.dist <- function( x, y=NULL, method = "euclidean",
         
       # EXPLICIT-STORAGE-FORMAT     
       if(max(n1,n2,nnz) > 2147483647 - 1 | getOption("spam.force64"))
-        SS <- .format64
+        SS <- .format64()
       else
         SS <- .format32
         
